@@ -93,7 +93,7 @@ def run(meter, duration):
         'rotations': np.zeros(num_sensors).tolist(),
         'scale_factor': 1.0,
         'merge': True,
-        'pq': True})
+        'polar': False})
 
     my_prep = prep.Prep()
     prep_future = asyncio.ensure_future(
