@@ -118,9 +118,9 @@ class ConfigureCmd(Command):
         process_config = configparser.ConfigParser()
         if(legacy):
             # PQ with separate stream for each phase
-            cmd = "nilm-filter-rawtoprep %s --pq" % name
+            cmd = "nilm-filter-rawtoprep %s" % name
         else:
-            # Phase / magnitude with one combined stream
+            # PQ with one combined stream
             cmd = "nilm-filter-rawtoprep %s --merge-prep" % name
         process_config['Main'] = {"name": "%s process" % name,
                                   "description":
