@@ -44,7 +44,7 @@ config:
     'nharm': 4          #number of odd harmonics to compute
     'scale_factor': 1.0 #scale result to watts
     'merge': True       #set to use a single prep output stream
-    'pq': False         #set to compute PQ data (clear to compute mag/phase)
+    'polar': False      #compute polar data (mag/phase) instead of PQ
  }
 """
 
@@ -167,13 +167,13 @@ class Prep(FilterModule):
                             Fk = F[2 * k + 1] * \
                                 np.e**(rot * 1j * (2 * k + 1)) / lag_correction
                             # compute output values
-                            if self.pq:
-                                out_a = -np.imag(Fk) * self.scale_factor  # Pk
-                                out_b = -np.real(Fk) * self.scale_factor  # Qk
-                            else:
-
+                            if self.polar:
                                 out_a = np.abs(Fk) * self.scale_factor  # VA
                                 out_b = (np.angle(Fk)+np.pi/2)*2/np.pi  # pf
+                            else:
+                                out_a = -np.imag(Fk) * self.scale_factor  # Pk
+                                out_b = -np.real(Fk) * self.scale_factor  # Qk
+
                             out[0, ph * nharm * 2 + 2 * k + 1] = out_a
                             out[0, ph * nharm * 2 + 2 * k + 2] = out_b
 
@@ -226,7 +226,7 @@ class Prep(FilterModule):
         self.nharm = config['nharm']
         self.scale_factor = config['scale_factor']
         self.merge = config['merge']
-        self.pq = config['pq']
+        self.polar = config['polar']
         
 
 def main():
