@@ -72,11 +72,11 @@ class RawToPrep(FilterModule):
                             action="store_true",
                             dest="merge_prep",
                             help="store prep in a single stream")
-        # --pq = False
-        parser.add_argument("--pq",
+        # --polar = False
+        parser.add_argument("--polar",
                             action="store_true",
-                            dest="pq",
-                            help="compute PQ instead of mag/phase")
+                            dest="polar",
+                            help="compute mag,phase instead of PQ")
 
     async def run(self, parsed_args, inputs, outputs):
 
@@ -98,7 +98,7 @@ class RawToPrep(FilterModule):
             'sinefit':        self._build_sinefit_configs(my_meter),
             'prep':           self._build_prep_configs(my_meter,
                                                        parsed_args.merge_prep,
-                                                       parsed_args.pq)
+                                                       parsed_args.polar)
         }
 
         tasks = self._run_filters_as_tasks(
@@ -223,7 +223,7 @@ class RawToPrep(FilterModule):
         config['max_freq'] = 70
         return config
 
-    def _build_prep_configs(self, meter, merge_output, pq):
+    def _build_prep_configs(self, meter, merge_output, polar):
 
         def _compute_rotations(meter):
             if(meter['type'] == 'noncontact'):
@@ -255,7 +255,7 @@ class RawToPrep(FilterModule):
         config['rotations'] = _compute_rotations(meter)
         config['scale_factor'] = _compute_scale_factor(meter)
         config['merge'] = merge_output
-        config['pq'] = pq
+        config['polar'] = polar
         return config
 
     
